######################################################################
# Copyright (c) Boris Baldassari, Adrien Luxey-Bitri
#
# This program and the accompanying materials are made
# available under the terms of the Eclipse Public License 2.0
# which is available at https://www.eclipse.org/legal/epl-2.0/
#
# SPDX-License-Identifier: EPL-2.0
######################################################################

"""
This module provides a set of example functions to learn Python.

Use with `pytest test_intro_python.py -v`.
"""

# Used to deal with dates/time.
from time import gmtime, strftime

def add_ints(a: int, b: int):
    """
    Adds two integers and returns the outcome.

    Returns an integer

    Parameters:
    - `a`: First integer to add.
    - `b`: Second integer to add.
    """
    out = a + b

    return out


def format_date(timestamp: int):
    """
    Converts a timestamp string to a RFC2616 (HTTP) date format.
    
    Returns a RFC2616-formatted date as a string, e.g. Fri, 19 Jan 2024 12:41:41 GMT

    Parameters:
    - `timestamp`: A string representing the timestamp to convert.
    """
    # Convert from timestamp to time object.
    mytime = gmtime(timestamp)
    
    # Convert time object to our format.
    return strftime('%a, %d %b %Y %H:%M:%S GMT', mytime)


def get_path_from_http_get(http_request: str):
    """
    Parses a typical HTTP request [1] and returns the path part.
    [1] GET /prise_en_main/ HTTP/2

    Returns the path part of the request as a string.
    Throws a ValueError exception if the input string is malformed.

    Parameters:
    - `http_request`: The HTTP request sting to parse. 
    """
    parsed = http_request.split(' ')

    if (parsed[0] != 'GET') or (len(parsed) != 3):
        raise ValueError('Input string not a proper GET.')
        
    return parsed[1]


if __name__ == "__main__":
    # Parse command-line arguments
    print("Printed in intro_python module.")
