 ######################################################################
# Copyright (c) Boris Baldassari, Adrien Luxey-Bitri
#
# This program and the accompanying materials are made
# available under the terms of the Eclipse Public License 2.0
# which is available at https://www.eclipse.org/legal/epl-2.0/
#
# SPDX-License-Identifier: EPL-2.0
######################################################################

"""
Script to test the intro_python.py module.

Use with `pytest test_intro_python.py -v`.
"""

# Needed for all test files.
import pytest

# This is the module we want to test.
import intro_python as target


def test_add_ints():
    """ Tests add_integer with various inputs.
    """
    assert target.add_ints(2, 3) == 5
    assert target.add_ints(6, 0) == 6
    assert target.add_ints(0, 7) == 7


def test_format_date():
    """ Tests the date_format function. """
    assert target.format_date(650936100) == 'Fri, 17 Aug 1990 23:35:00 GMT'


# Define several cases for parametrization.
mytests = [
    (959347394, 'Fri, 26 May 2000 13:23:14 GMT'),
    (1705674994, 'Fri, 19 Jan 2024 14:36:34 GMT'),
]

@pytest.mark.parametrize("timestamp, isotime", mytests)
def test_date_format_parameterized(timestamp, isotime):
    """ 
    Tests the date_format function.

    Uses various timestamp strings and checks it returns the correct
    ISO8601 format.
    """
    assert target.format_date(timestamp) == isotime


# Define several cases for parametrization.
mytests = [
    ('GET /index.html HTTP/2', '/index.html'), 
    ('GET /img/logo.svg HTTP/1.1', '/img/logo.svg')
]

@pytest.mark.parametrize("http_request, path", mytests)
def test_get_path_from_http_get(http_request, path):
    """
    Tests get_path_from_http_get with various request strings.
    """
    assert target.get_path_from_http_get(http_request) == path
    
    
def test_get_path_from_http_get_exception():
    """
    Tests get_path_from_http_get with wrong cases so it generates exceptions.
    """    
    with pytest.raises(Exception) as e:
        target.get_path_from_http_get('GET/i ndex.html HTTP/2')
        
    assert str(e.value) == 'Input string not a proper GET.'
    
    with pytest.raises(Exception) as e:
        target.get_path_from_http_get('GET/index.html HTTP/2')
        
    assert str(e.value) == 'Input string not a proper GET.'
    
