######################################################################
# Copyright (c) Boris Baldassari, Adrien Luxey-Bitri
#
# This program and the accompanying materials are made
# available under the terms of the Eclipse Public License 2.0
# which is available at https://www.eclipse.org/legal/epl-2.0/
#
# SPDX-License-Identifier: EPL-2.0
######################################################################

"""
Script to test the intro_python.py module.

Use with `pytest tests/test_intro_python.py`.
"""

# Needed for all test files.
import pytest

# This is the module we want to test.
import intro_python as target


def test_add_ints():
    """ Tests add_integer with various inputs.
    """
    assert target.add_ints(2, 3) == 5
    assert target.add_ints(6, 0) == 6
    assert target.add_ints(0, 7) == 7


def test_format_date():
    """ Tests the date_format function.

    TODO: This test function (and documentation) should be updated.
    """
    assert 1 == ""

    
# Define several cases for parametrisation.
mytests = [
    ('GET /index.html HTTP/2', '/index.html'), 
    ('GET /img/logo.svg HTTP/1.1', '/img/logo.svg')
]

@pytest.mark.parametrize("http_request, path", mytests)
def test_get_path_from_http_get(http_request, path):
    """
    Tests get_path_from_http_get with various request strings.
    """
    assert target.get_path_from_http_get(http_request) == path
    
    
def test_get_path_from_http_get_exception():
    """
    Tests get_path_from_http_get with wrong cases so it generates exceptions.
    """    
    with pytest.raises(Exception) as e:
        target.get_path_from_http_get('GET/i ndex.html HTTP/2')
        
    assert str(e.value) == 'Input string not a proper GET.'
    
    with pytest.raises(Exception) as e:
        target.get_path_from_http_get('GET/index.html HTTP/2')
        
    assert str(e.value) == 'Input string not a proper GET.'
    
    
    
    
