######################################################################
# Copyright (c) Boris Baldassari, Adrien Luxey-Bitri
#
# This program and the accompanying materials are made
# available under the terms of the Eclipse Public License 2.0
# which is available at https://www.eclipse.org/legal/epl-2.0/
#
# SPDX-License-Identifier: EPL-2.0
######################################################################

"""
This module plays with sockets.

More info.

"""

import argparse
import socket
import sys


def _parse_args():
    """
    Parses arguments from command line.
    """
    parser = argparse.ArgumentParser(description="Utilities to use network sockets.")
    parser.add_argument('-p', '--port', 
                        help='Port number to open')
    args = parser.parse_args()

    if args.port is None:
        print("Please provide a port for the connection.")
        print(parser.print_help())
        sys.exit(1)
    else:
        print("Got port option set to:", args.port)        
        
    return args


def answer():
    """
    Returns an answer to the connection.

    :return: A string.
    """

    return "Gotcha.\n"


def server(port: int):
    """
    Opens a socket on a given port and listens to incoming
    requests. When a request comes in, accepts the connection,
    sends a message back and hangs up (closes), indefinitely.

    :param port: Port number to listen on.
    """
    s = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
    s.bind(("127.0.0.1", port))
    s.listen()
    while True:
        c, addr = s.accept()
        print('Got connection from', addr)
        #c.send(answer().encode('utf-8'))
        c.close()
    print("Fin de l'écoute.")
        
        
if __name__ == '__main__':

    # Parse command-line arguments
    args = _parse_args()
    
    # Start our server
    server(int(args.port))

    
